==========
Authorship
==========

The following people have contributed to pymad8:

* Stewart Boogert  
* Andrey Abramov
* Laurie Nevay
* Will Parker
* William Shields
* Jochem Snuverink
* Stuart Walker
* Marin Deniaud
